@@ -1,6 +1,6 @@
 package Lingua::EN::Tagger;
 
-our $VERSION = '0.22';
+our $VERSION = '0.26';
 
 use warnings;
 use strict;
@@ -530,7 +530,7 @@ sub _assign_tag {
 ############################################################################
 # _reset
 #
-# this subroutine will reset the preceeding tag to a sentence ender (PP).
+# this subroutine will reset the preceding tag to a sentence ender (PP).
 # This prepares the first word of a new sentence to be tagged correctly.
 ############################################################################
 sub _reset {
@@ -582,10 +582,10 @@ sub _classify_unknown_word {
     } elsif(m/[\)\]\}]/o){ # Right brackets
         $word = "*RRB*";
 
-    } elsif (m/-?(?:\p{IsDigit}+(?:\.\p{IsDigit}*)?|\.\p{IsDigit}+)/){ # Floating point number
+    } elsif (m/^-?(?:\p{IsDigit}+(?:\.\p{IsDigit}*)?|\.\p{IsDigit}+)$/){ # Floating point number
         $word = "*NUM*";
 
-    } elsif (m/^\p{IsDigit}+[\p{IsDigit}\/:-]+\p{IsDigit}/){ # Other number constructs
+    } elsif (m/^\p{IsDigit}+[\p{IsDigit}\/:-]+\p{IsDigit}$/){ # Other number constructs
         $word = "*NUM*";
 
     } elsif (m/^-?\p{IsDigit}+\p{IsWord}+$/o){  # Ordinal number
